pub struct AccountInfo {Show 13 fields
pub ch_acc_age_ind: Option<String>,
pub ch_acc_date: Option<String>,
pub ch_acc_change_ind: Option<String>,
pub ch_acc_change: Option<String>,
pub ch_acc_pw_change_ind: Option<String>,
pub nb_purchase_account: Option<String>,
pub provision_attempts_day: Option<String>,
pub txn_activity_year: Option<String>,
pub txn_activity_day: Option<String>,
pub ship_address_usage: Option<String>,
pub ship_address_usage_ind: Option<ShippingAddressUsage>,
pub ship_name_indicator: Option<String>,
pub suspicious_acc_activity: Option<SuspiciousAccActivity>,
}Expand description
Cardholder account information used for risk assessment.
Fields
ch_acc_age_ind: Option<String>Length of time that the cardholder has had the account (01–04).
ch_acc_date: Option<String>Date that the cardholder opened the account (YYYYMMDD).
ch_acc_change_ind: Option<String>Length of time since the last change to the account (01–04).
ch_acc_change: Option<String>Date the last account change occurred (YYYYMMDD).
ch_acc_pw_change_ind: Option<String>Length of time since the password last changed (01–04).
nb_purchase_account: Option<String>Number of transactions in the past 24 hours.
provision_attempts_day: Option<String>Number of add-card attempts in the past 24 hours.
txn_activity_year: Option<String>Number of transactions in the past year.
txn_activity_day: Option<String>Number of transactions in the previous 6 months.
ship_address_usage: Option<String>Date that the shipping address was first used (YYYYMMDD).
ship_address_usage_ind: Option<ShippingAddressUsage>Indicator for when the shipping address was first used (01–04).
ship_name_indicator: Option<String>Name on account vs shipping name match indicator.
suspicious_acc_activity: Option<SuspiciousAccActivity>Trait Implementations
Sourceimpl Clone for AccountInfo
impl Clone for AccountInfo
Sourcefn clone(&self) -> AccountInfo
fn clone(&self) -> AccountInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccountInfo
impl Debug for AccountInfo
Sourceimpl Default for AccountInfo
impl Default for AccountInfo
Sourcefn default() -> AccountInfo
fn default() -> AccountInfo
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AccountInfo
impl<'de> Deserialize<'de> for AccountInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more